@@ -41,7 +41,6 @@
 #'
 #' @export
 #'
-#' @seealso [derive_vars_last_dose()], [cut()], [create_single_dose_dataset()]
 derive_var_last_dose_grp <- function(dataset,
                                      dataset_ex,
                                      filter_ex = NULL,
@@ -57,38 +56,5 @@ derive_var_last_dose_grp <- function(dataset,
                                      right = TRUE,
                                      dose_var = EXDOSE,
                                      traceability_vars = NULL) {
-  deprecate_warn("0.11.0", "derive_var_last_dose_grp()", "derive_vars_joined()")
-  filter_ex <- assert_filter_cond(enexpr(filter_ex), optional = TRUE)
-  by_vars <- assert_vars(by_vars)
-  dose_date <- assert_symbol(enexpr(dose_date))
-  analysis_date <- assert_symbol(enexpr(analysis_date))
-  single_dose_condition <- assert_filter_cond(enexpr(single_dose_condition))
-  new_var <- assert_symbol(enexpr(new_var))
-  dose_var <- assert_symbol(enexpr(dose_var))
-
-  derive_vars_last_dose(
-    dataset = dataset,
-    dataset_ex = dataset_ex,
-    filter_ex = !!filter_ex,
-    by_vars = by_vars,
-    dose_id = dose_id,
-    dose_date = !!dose_date,
-    analysis_date = !!analysis_date,
-    single_dose_condition = !!single_dose_condition,
-    new_vars = exprs(!!dose_var),
-    traceability_vars = traceability_vars
-  ) %>%
-    mutate(
-      !!new_var :=
-        as.character(
-          cut(
-            !!dose_var,
-            breaks = !!grp_brks,
-            include.lowest = include_lowest,
-            right = right,
-            labels = !!grp_lbls
-          )
-        )
-    ) %>%
-    select(-!!dose_var, !!new_var)
+  deprecate_stop("0.11.0", "derive_var_last_dose_grp()", "derive_vars_joined()")
 }
