@@ -9,13 +9,13 @@ library(admiraldev)
 ## ---- message=FALSE, warning=FALSE--------------------------------------------
 library(admiral)
 library(dplyr, warn.conflicts = FALSE)
-library(admiral.test)
+library(pharmaversesdtm)
 library(lubridate)
 
-data("admiral_ae")
+data("ae")
 data("admiral_adsl")
 
-ae <- convert_blanks_to_na(admiral_ae)
+ae <- convert_blanks_to_na(ae)
 adsl <- admiral_adsl
 
 ## ----echo = FALSE-------------------------------------------------------------
