@@ -10,9 +10,21 @@ test_that("derive_vars_aage Test 1: duration and unit variable are added", {
   expect_dfs_equal(derive_vars_aage(input), expected_output, keys = c("BRTHDT", "RANDDT"))
 })
 
+## Test 2: duration and unit variable are added ----
+test_that("derive_vars_aage Test 2: Error is thrown when age_unit is not proper unit", {
+  input <- tibble::tribble(
+    ~BRTHDT, ~RANDDT,
+    ymd("1999-09-09"), ymd("2020-02-20")
+  )
+  expect_error(
+    derive_vars_aage(input, age_unit = "centuries"),
+    "`age_unit` must be one of 'years', 'months', 'weeks', 'days', 'hours', 'minutes' or 'seconds' but is 'centuries'" # nolint
+  )
+})
+
 # derive_var_age_years ----
-## Test 2: derive_var_age_years works as expected when AGEU exists ----
-test_that("derive_var_age_years Test 2: derive_var_age_years works as expected when AGEU exists", {
+## Test 3: derive_var_age_years works as expected when AGEU exists ----
+test_that("derive_var_age_years Test 3: derive_var_age_years works as expected when AGEU exists", {
   input <- tibble::tibble(
     AGE = c(12, 24, 36, 48, 60),
     AGEU = c("months", "months", "months", "months", "months")
@@ -26,9 +38,9 @@ test_that("derive_var_age_years Test 2: derive_var_age_years works as expected w
   expect_dfs_equal(derive_var_age_years(input, AGE, new_var = AAGE), expected_output, keys = "AGE")
 })
 
-## Test 3: derive_var_age_years works as expected when AGEU doesn't exist and
+## Test 4: derive_var_age_years works as expected when AGEU doesn't exist and
 ## `age_unit` is used ----
-test_that("derive_var_age_years Test 3: derive_var_age_years works as expected
+test_that("derive_var_age_years Test 4: derive_var_age_years works as expected
           when AGEU doesn't exist and `age_unit` is used", {
   input <- tibble::tibble(AGE = c(12, 24, 36, 48, 60))
 
@@ -43,8 +55,8 @@ test_that("derive_var_age_years Test 3: derive_var_age_years works as expected
   )
 })
 
-## Test 4: Error is thrown when age_unit is not proper unit ----
-test_that("derive_var_age_years Test 4: Error is thrown when age_unit is not proper unit", {
+## Test 5: Error is thrown when age_unit is not proper unit ----
+test_that("derive_var_age_years Test 5: Error is thrown when age_unit is not proper unit", {
   input <- data.frame(AGE = c(12, 24, 36, 48))
   expect_error(
     derive_var_age_years(input, AGE, age_unit = "month", new_var = AAGE),
@@ -52,17 +64,17 @@ test_that("derive_var_age_years Test 4: Error is thrown when age_unit is not pro
   )
 })
 
-## Test 5: Error is issued if age_unit is missing ----
-test_that("derive_var_age_years Test 5: Error is issued if age_unit is missing", {
+## Test 6: Error is issued if age_unit is missing ----
+test_that("derive_var_age_years Test 6: Error is issued if age_unit is missing", {
   input <- data.frame(AGE = c(12, 24, 36, 48))
   expect_error(
     derive_var_age_years(input, AGE, new_var = AAGE)
   )
 })
 
-## Test 6: Warning is issued if age_unit is not null, but the 'unit' variable
+## Test 7: Warning is issued if age_unit is not null, but the 'unit' variable
 ##         corresponding to age_var stores more than one unique value. ----
-test_that("derive_var_age_years Test 6: Warning is issued if age_unit is not
+test_that("derive_var_age_years Test 7: Warning is issued if age_unit is not
           null, but the 'unit' variable corresponding to age_var stores more
           than one unique value.", {
   input <- tibble::tribble(
@@ -81,8 +93,8 @@ test_that("derive_var_age_years Test 6: Warning is issued if age_unit is not
 })
 
 
-## Test 7: Error is issued if age_unit consists of more than one unique value. ----
-test_that("derive_var_age_years Test 7: Error is issued if age_unit consists of
+## Test 8: Error is issued if age_unit consists of more than one unique value. ----
+test_that("derive_var_age_years Test 8: Error is issued if age_unit consists of
           more than one unique value.", {
   input <- tibble::tribble(
     ~AGE,   ~AGEU,
@@ -99,10 +111,10 @@ test_that("derive_var_age_years Test 7: Error is issued if age_unit consists of
   )
 })
 
-## Test 8: The 'unit' variable corresponding to age_var will be considered as
+## Test 9: The 'unit' variable corresponding to age_var will be considered as
 ##         storing one unique unit, if values differ only by case, i.e.
 ##         'months', 'Months', 'MONTHS' considered same unit, etc. ----
-test_that("derive_var_age_years Test 8: The 'unit' variable corresponding to
+test_that("derive_var_age_years Test 9: The 'unit' variable corresponding to
           age_var will be considered as storing one unique unit, if values
           differ only by case, i.e. 'months', 'Months', 'MONTHS' considered same
           unit, etc.", {
@@ -135,10 +147,10 @@ test_that("derive_var_age_years Test 8: The 'unit' variable corresponding to
   )
 })
 
-## Test 9: Warning is issued if age_unit is not null, but the 'unit' variable
-##         corresponding to age_var stores one unique unit that is not
-##         equivalent to age_unit. ----
-test_that("derive_var_age_years Test 9: Warning is issued if age_unit is not
+## Test 10: Warning is issued if age_unit is not null, but the 'unit' variable
+##          corresponding to age_var stores one unique unit that is not
+##          equivalent to age_unit. ----
+test_that("derive_var_age_years Test 10: Warning is issued if age_unit is not
           null, but the 'unit' variable corresponding to age_var stores one
           unique unit that is not equivalent to age_unit.", {
   input <- tibble::tribble(
